make_validity_registration

Function make_validity_registration 

pub fn make_validity_registration<W: Write, E: Iterator<Item = (StorePath<S1>, R)>, R: Iterator<Item = StorePath<S2>> + ExactSizeIterator, S1: AsRef<str>, S2: AsRef<str>>(
    w: &mut W,
    elems: E,
) -> Result
Produces the format that Nix calls “makeValidityRegistration” and describes as: “A string accepted by decodeValidPathInfo() that registers the specified paths as valid.” Explained differently, this is the text format used in exportReferencesGraph, in the non-structured attrs case, which can be passed to nix-store --register-validity. We don’t implement the showDerivers and showHash functionality, as that doesn’t seem to be used for exportReferenceGraph.